(* Support for widget manipulations *)
type widget
      	(* widget is an abstract type *)

val default_toplevel_widget : widget
      	(* The default toplevel widget is ".", of type "toplevel" *)

val widget_atom : widget -> string -> widget

(* The following functions are used internally.
   There is normally no need for them in users programs *)

val dummy_widget : widget
      	(* used as context *)
          
val widget_name : widget -> string
      (* Returns the name (tk "path") of a widget *)
val  widget_class : widget-> string
      (* Returns the class of a widget *)

val new_widget_atom : string -> widget -> widget
val new_named_widget : string -> widget -> string -> widget
      (* Abstract creation functions *)
val get_widget_atom : string -> widget

val remove_widget : widget -> unit

val widget_any_table : string list
val widget_button_table : string list
val widget_canvas_table : string list
val widget_checkbutton_table : string list
val widget_entry_table : string list
val widget_frame_table : string list
val widget_label_table : string list
val widget_listbox_table : string list
val widget_menu_table : string list
val widget_menubutton_table : string list
val widget_message_table : string list
val widget_radiobutton_table : string list
val widget_scale_table : string list
val widget_scrollbar_table : string list
val widget_text_table : string list
val widget_toplevel_table : string list
val chk_sub : string -> 'a list -> 'a -> unit
val check_widget_class : widget -> string list -> unit
      (* Widget subtyping *)
exception IllegalWidgetType of string
      (* Raised when widget command applied illegally*)

(* Extensible buffers *)
type extensible_buffer
val new_buffer : unit -> extensible_buffer
val   print_in_buffer : extensible_buffer -> string -> unit
val   get_buffer : extensible_buffer -> string


val catenate_sep : string -> string list -> string
val split_str : (char -> bool) -> string -> string list
      (* Various string manipulations *)



type symbol = string
      (* A simpler "string" type *)

val cCAMLtoTKsymbol : symbol -> string
val cTKtoCAMLsymbol : string -> symbol
